@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package asn1
@@ -266,13 +261,13 @@ func TestDecoder_Read(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Decoder{
 				data: tt.fields.data,
 			}
-
 			got, got1, err := c.Read(tt.args.tag, tt.args.compareByte)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Decoder.Read() error = %v, wantErr %v", err, tt.wantErr)
@@ -366,13 +361,13 @@ func TestDecoder_readLength(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Decoder{
 				data: tt.fields.data,
 			}
-
 			got, gotOffset, err := c.readLength()
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Decoder.readLength() error = %v, wantErr %v", err, tt.wantErr)
@@ -459,13 +454,13 @@ func TestDecoder_ReadEnd(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Decoder{
 				data: tt.fields.data,
 			}
-
 			got, err := c.ReadEnd()
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Decoder.ReadEnd() error = %v, wantErr %v", err, tt.wantErr)
@@ -518,13 +513,13 @@ func TestDecoder_Peek(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Decoder{
 				data: tt.fields.data,
 			}
-
 			got, err := c.Peek()
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Decoder.Peek() error = %v, wantErr %v", err, tt.wantErr)
@@ -597,13 +592,13 @@ func TestDecoder_DecodeUniversal(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Decoder{
 				data: tt.fields.data,
 			}
-
 			got, err := c.DecodeUniversal()
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Decoder.DecodeUniversal() error = %v, wantErr %v", err, tt.wantErr)
@@ -729,13 +724,13 @@ func TestDecoder_DecodeUtf8(t *testing.T) {
 		},
 	}
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Decoder{
 				data: tt.fields.data,
 			}
-
 			got, err := c.DecodeUTF8()
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Decoder.DecodeUtf8() error = %v, wantErr %v", err, tt.wantErr)
@@ -816,13 +811,13 @@ func TestDecoder_DecodeInteger(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Decoder{
 				data: tt.fields.data,
 			}
-
 			got, err := c.DecodeInteger()
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Decoder.DecodeInteger() error = %v, wantErr %v", err, tt.wantErr)
@@ -875,13 +870,13 @@ func TestDecoder_ReadByte(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Decoder{
 				data: tt.fields.data,
 			}
-
 			got, err := c.ReadByte()
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Decoder.ReadByte() error = %v, wantErr %v", err, tt.wantErr)
@@ -928,13 +923,13 @@ func TestDecoder_readWithOutLength(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Decoder{
 				data: tt.fields.data,
 			}
-
 			got, err := c.readWithOutLength()
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Decoder.readWithOutLength() error = %v, wantErr %v", err, tt.wantErr)
@@ -989,13 +984,13 @@ func TestDecoder_readWithLength(t *testing.T) {
 	}
 
 	for _, tt := range tests {
+		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			t.Parallel()
 
 			c := &Decoder{
 				data: tt.fields.data,
 			}
-
 			got, err := c.readWithLength(tt.args.length)
 			if (err != nil) != tt.wantErr {
 				t.Fatalf("Decoder.readWithLength() error = %v, wantErr %v", err, tt.wantErr)
