@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package ember
@@ -409,7 +404,7 @@ func (el *Element) handleFunctionContext(context *asn1.Decoder, tag byte) (*asn1
 		}
 	}
 
-	for range n {
+	for i := 0; i < n; i++ {
 		_, err := context.ReadByte()
 		if err != nil {
 			return nil, errs.Wrapf(err, "failed to read over used bytes")
@@ -475,7 +470,7 @@ func (el *Element) handleNodeContext(context *asn1.Decoder, tag byte) (*asn1.Dec
 		}
 	}
 
-	for range n {
+	for i := 0; i < n; i++ {
 		_, err := context.ReadByte()
 		if err != nil {
 			return nil, errs.Wrapf(err, "failed to read over used bytes")
@@ -523,23 +518,23 @@ func (el *Element) handleParameterContext(context *asn1.Decoder, tag byte) (*asn
 
 		el.Value = value
 	case asn1.ContextByte(3):
-		var minimum any
+		var min any
 
-		n, err = asn1.DecodeAny(context.Bytes(), &minimum)
+		n, err = asn1.DecodeAny(context.Bytes(), &min)
 		if err != nil {
 			return nil, errs.Wrap(err, "failed to decode is min")
 		}
 
-		el.Minimum = minimum
+		el.Minimum = min
 	case asn1.ContextByte(4):
-		var maximum any
+		var max any
 
-		n, err = asn1.DecodeAny(context.Bytes(), &maximum)
+		n, err = asn1.DecodeAny(context.Bytes(), &max)
 		if err != nil {
 			return nil, errs.Wrap(err, "failed to decode is max")
 		}
 
-		el.Maximum = maximum
+		el.Maximum = max
 	case asn1.ContextByte(5):
 		var access int
 
@@ -643,7 +638,7 @@ func (el *Element) handleParameterContext(context *asn1.Decoder, tag byte) (*asn
 
 	el.setDefaultElementValue()
 
-	for range n {
+	for i := 0; i < n; i++ {
 		_, err := context.ReadByte()
 		if err != nil {
 			return nil, errs.Wrapf(err, "failed to read over used bytes")
@@ -693,8 +688,8 @@ func (el *Element) setValue(context *asn1.Decoder) (any, int, error) {
 }
 
 func (el *Element) setDefaultElementValue() {
-	// No default for enum data type as value for enum data type defines witch of string lines in enum field to use.
-	// and none should be used if there is no value
+	// no default for enum data type as value for enum data type defines witch of string lines in enum field to use.
+	// and none should be used if there no value
 	if el.Value == nil {
 		switch el.ValueType {
 		case valueTypeInt, valueTypeReal:
