@@ -1,20 +1,15 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 package plugin
@@ -30,9 +25,9 @@ type session struct {
 }
 
 type pluginConfig struct {
-	System plugin.SystemOptions `conf:"optional"` //nolint:staticcheck
+	plugin.SystemOptions `conf:"optional,name=System"`
 	// Timeout is the amount of time to wait for a server to respond when
-	// first connecting and on follow-up operations in the session.
+	// first connecting and on follow up operations in the session.
 	Timeout int `conf:"optional,range=1:30,default=3"`
 	// KeepAlive is a time to wait before unused connections will be closed.
 	KeepAlive int `conf:"optional,range=60:900,default=300"`
@@ -48,7 +43,7 @@ type pluginConfig struct {
 func (p *emberPlugin) Configure(global *plugin.GlobalOptions, options any) {
 	pConfig := &pluginConfig{}
 
-	err := conf.UnmarshalStrict(options, pConfig)
+	err := conf.Unmarshal(options, pConfig)
 	if err != nil {
 		p.Errf("cannot unmarshal configuration options: %s", err.Error())
 
@@ -67,7 +62,7 @@ func (p *emberPlugin) Configure(global *plugin.GlobalOptions, options any) {
 func (*emberPlugin) Validate(options any) error {
 	var opts pluginConfig
 
-	err := conf.UnmarshalStrict(options, &opts)
+	err := conf.Unmarshal(options, &opts)
 	if err != nil {
 		return errs.Wrap(err, "failed to unmarshal configuration options")
 	}
